(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('apollo-link'), require('apollo-utilities')) :
    typeof define === 'function' && define.amd ? define(['exports', 'apollo-link', 'apollo-utilities'], factory) :
    (factory((global.apolloLink = global.apolloLink || {}, global.apolloLink.maxage = {}),global.apolloLink.core,null));
}(this, (function (exports,apolloLink,apolloUtilities) { 'use strict';

    var __extends = (undefined && undefined.__extends) || (function () {
        var extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return function (d, b) {
            extendStatics(d, b);
            function __() { this.constructor = d; }
            d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
        };
    })();
    // turns 10d into number of ms
    function msTime(str) {
        var types = { ms: 1 };
        types.s = types.ms * 1000;
        types.m = types.s * 60;
        types.h = types.m * 60;
        types.d = types.h * 24;
        types.w = types.d * 7;
        var num = parseInt(str.replace(/[a-z]+/i, ''), 10);
        var type = str.replace(/[0-9]+/, '');
        return num * types[type];
    }
    var MaxAgeLink = /** @class */ (function (_super) {
        __extends(MaxAgeLink, _super);
        function MaxAgeLink(options) {
            var _this = _super.call(this) || this;
            _this.options = options;
            _this.scheduled = new Map();
            return _this;
        }
        MaxAgeLink.prototype.request = function (op, forward) {
            var _this = this;
            var ctx = op.getContext();
            var isQuery = apolloUtilities.getMainDefinition(op.query).operation === 'query';
            if (!isQuery || !ctx.maxAge) {
                return forward(op);
            }
            var key = this.toKey(op);
            if (this.shouldUseNetwork(key)) {
                var now = new Date();
                var maxAge = typeof ctx.maxAge === 'string' ? msTime(ctx.maxAge) : ctx.maxAge;
                var expirationDate = new Date(now.getTime() + maxAge);
                this.schedule(key, expirationDate);
                return forward(op);
            }
            return new apolloLink.Observable(function (observer) {
                try {
                    var data = _this.options.cache.readQuery({
                        query: op.query,
                        variables: op.variables,
                    });
                    observer.next({ data: data });
                    observer.complete();
                }
                catch (e) {
                    observer.error(e);
                }
            });
        };
        MaxAgeLink.prototype.shouldUseNetwork = function (key) {
            return this.isExpired(key) || !this.scheduled.has(key);
        };
        MaxAgeLink.prototype.isExpired = function (key) {
            return this.scheduled.get(key) < new Date();
        };
        MaxAgeLink.prototype.schedule = function (key, date) {
            this.scheduled.set(key, date);
        };
        MaxAgeLink.prototype.toKey = function (op) {
            return this.options.toKey ? this.options.toKey(op) : op.toKey();
        };
        return MaxAgeLink;
    }(apolloLink.ApolloLink));

    exports.MaxAgeLink = MaxAgeLink;

    Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=bundle.umd.js.map
